@@ -270,7 +270,7 @@ class Assets(WMLResource):
                             else:
                                     put_response = requests.put(
                                         self._wml_credentials['url'] + attachment_url,
-                                        files={'file': _file}
+                                        files={'file': (name, _file, 'file')}
                                     )
                         if put_response.status_code == 201 or put_response.status_code == 200:
                             # Step4: Complete attachment
