@@ -80,10 +80,11 @@ class ExperimentIterableDataset(IterableDataset):
         self.experiment_metadata = experiment_metadata
         self.enable_sampling = enable_sampling
         self._wml_client = getattr(connection, "_wml_client", None)
+        if self._wml_client is None:
+            self._wml_client = kwargs.get("_wml_client", None)
         self.binary_data = binary_data
         self.sampling_type = sampling_type
         self.read_to_file = kwargs.get('read_to_file')
-
         self.authorized = self._wml_check_authorization()
 
         # Note: convert to dictionary if we have object from WML client
@@ -127,6 +128,7 @@ class ExperimentIterableDataset(IterableDataset):
                 data_location=dict_connection,
                 data_size_limit=sample_size_limit,
                 flight_parameters=kwargs.get("flight_parameters", {}),
+                extra_interaction_properties=kwargs.get("extra_interaction_properties",{}),
                 fallback_to_one_connection=kwargs.get(
                     "fallback_to_one_connection", True
                 ),
