@@ -593,38 +593,6 @@ class BaseDeployment(ABC):
         """Protected method to create a deployment."""
         pass
 
-    def _promote_model(self,
-                       model_id: str,
-                       project_id: str,
-                       space_id: str):
-        """
-        Protected method to promote a model from project to deployment space.
-        Returns id of promoted model.
-        """
-
-        promote_payload = {"spaceId": space_id,
-                           "projectId": project_id,
-                           "assetType": "wml_model",
-                           "assetDescription": "Model promoted by ibm_wml client"}
-        promote_href = self._source_workspace.wml_client.service_instance._href_definitions.promote_asset_href(model_id)
-        response = requests.post(
-            promote_href,
-            headers=self._source_workspace.wml_client._get_headers(),
-            json=promote_payload
-        )
-        promotion_details = self._source_workspace.wml_client.repository._handle_response(200, u'promote model asset',
-                                                                                          response)
-
-        try:
-            promoted_model_id = promotion_details['promotedAsset']['asset_id']
-        except KeyError as key_err:
-            raise ModelPromotionFailed(project_id, space_id, promotion_details, reason=key_err)
-
-        return promoted_model_id
-
-
-
-
     def _publish_model(self,
                        pipeline_model: Union['Pipeline', str],
                        meta_props: Dict) -> str:
@@ -652,9 +620,9 @@ class BaseDeployment(ABC):
 
             project_asset_id = self._source_workspace.wml_client.repository.get_model_id(published_model_details)
 
-            asset_id = self._promote_model(model_id=project_asset_id,
-                                           project_id=self._source_workspace.project_id,
-                                           space_id=self._target_workspace.space_id)
+            asset_id = self._source_workspace.wml_client.repository.promote_model(model_id=project_asset_id,
+                                                                                  source_project_id=self._source_workspace.project_id,
+                                                                                  target_space_id=self._target_workspace.space_id)
 
         else:
             published_model_details = self._target_workspace.wml_client.repository.store_model(
