@@ -825,7 +825,7 @@ class Deployments(WMLResource):
         params = self._client._params()
         details = self.get_details(virtual_deployment_uid)
         download_url = self.get_download_url(details)
-        if self._client.CLOUD_PLATFORM_SPACES or self._client.ICP_35 or self._client.ICP_40:
+        if any([self._client.CLOUD_PLATFORM_SPACES, self._client.ICP_35, self._client.ICP_40, self._client.ICP_45]):
             download_url = download_url + "&version=" + self._client.version_param
             params = None
         response = requests.get(
