@@ -26,7 +26,8 @@ from ibm_watson_machine_learning.utils.autoai.errors import LocalInstanceButRemo
     TSNotSupported, ParamOutOfRange, ImputationListNotSupported
 from ibm_watson_machine_learning.utils.autoai.utils import check_dependencies_versions, \
     validate_additional_params_for_optimizer, validate_optimizer_enum_values, \
-    translate_imputation_string_strategy_to_enum, translate_estimator_string_to_enum
+    translate_imputation_string_strategy_to_enum, translate_estimator_string_to_enum, \
+    translate_batched_estimator_string_to_enum
 from ibm_watson_machine_learning.workspace import WorkSpace
 from .engines import WMLEngine
 from .optimizers import LocalAutoPipelines, RemoteAutoPipelines
@@ -165,6 +166,8 @@ class AutoAI(BaseExperiment):
                   include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms',
                                                       'ForecastingAlgorithms']] = None,
                   daub_include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None, # deprecated
+                  #include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms',
+                  #                                                'BatchedRegressionAlgorithms']] = None,
                   backtest_num: int = None,
                   lookback_window: int = None,
                   forecast_window: int = None,
@@ -403,6 +406,19 @@ class AutoAI(BaseExperiment):
         >>>    )
         """
 
+        # Docs for include_batched_ensemble_estimators:
+        # include_batched_ensemble_estimators: List[
+        #     Union['BatchedClassificationAlgorithms', 'BatchedRegressionAlgorithms']], optional
+        # List of batched ensemble estimators to include in computation process.
+        #
+        # See: AutoAI.BatchedClassificationAlgorithms, AutoAI.BatchedRegressionAlgorithms
+
+        include_batched_ensemble_estimators = None
+        if 'include_batched_ensemble_estimators' in kwargs:
+            include_batched_ensemble_estimators = kwargs.pop('include_batched_ensemble_estimators')  # TODO to be removed
+        elif 'global_stage_include_batched_ensemble_estimators' in kwargs:
+            include_batched_ensemble_estimators = kwargs.pop('global_stage_include_batched_ensemble_estimators')  # TODO to be removed
+
         # TODO: Pass the sampling_type doc description, when adding support for that
         # sampling_type: str, optional
         #     Type of sampling data for training. One of SamplingTypes enum values.
@@ -456,14 +472,19 @@ class AutoAI(BaseExperiment):
         def translate_str_include_only_estimators_param(x):
             return [translate_estimator_string_to_enum(estimator) for estimator in x]
 
+        def translate_str_include_batched_ensemble_estimators_param(x):
+            return [translate_batched_estimator_string_to_enum(estimator) for estimator in x]
+
         categorical_imputation_strategy = translate_str_imputation_param(categorical_imputation_strategy)
         numerical_imputation_strategy = translate_str_imputation_param(numerical_imputation_strategy)
         include_only_estimators = translate_str_include_only_estimators_param(include_only_estimators) if include_only_estimators else None
+        include_batched_ensemble_estimators = translate_str_include_batched_ensemble_estimators_param(include_batched_ensemble_estimators) if include_batched_ensemble_estimators else None
 
         validate_optimizer_enum_values(
             prediction_type=prediction_type,
             daub_include_only_estimators=daub_include_only_estimators,
             include_only_estimators=include_only_estimators,
+            include_batched_ensemble_estimators=include_batched_ensemble_estimators,
             cognito_transform_names=cognito_transform_names,
             imputation_strategies=[x for y in list(filter(None, [categorical_imputation_strategy, numerical_imputation_strategy])) for x in (y if type(y) is list else [y])],
             scoring=scoring,
@@ -512,6 +533,7 @@ class AutoAI(BaseExperiment):
                 max_num_daub_ensembles=max_number_of_estimators,
                 train_sample_rows_test_size=train_sample_rows_test_size,
                 include_only_estimators=include_only_estimators,
+                include_batched_ensemble_estimators=include_batched_ensemble_estimators,
                 cognito_transform_names=cognito_transform_names,
                 positive_label=positive_label,
                 _force_local_scenario=kwargs.get('_force_local_scenario', False),
@@ -547,6 +569,7 @@ class AutoAI(BaseExperiment):
                 ),
                 train_sample_rows_test_size=train_sample_rows_test_size,
                 include_only_estimators=include_only_estimators,
+                include_batched_ensemble_estimators=include_batched_ensemble_estimators,
                 backtest_num=backtest_num,
                 lookback_window=lookback_window,
                 forecast_window=forecast_window,
