@@ -108,6 +108,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
                  max_num_daub_ensembles: int = 1,
                  train_sample_rows_test_size: float = 1.,
                  include_only_estimators: List[Union['ClassificationAlgorithms', 'RegressionAlgorithms']] = None,
+                 include_batched_ensemble_estimators: List[Union['BatchedClassificationAlgorithms', 'BatchedRegressionAlgorithms']] = None,
                  cognito_transform_names: List['Transformers'] = None,
                  positive_label: str = None,
                  _data_clients: List[Tuple['DataConnection', 'resource']] = None,
@@ -157,6 +158,7 @@ class LocalAutoPipelines(BaseAutoPipelines):
                 'max_num_daub_ensembles': int(max_num_daub_ensembles),
                 'train_sample_rows_test_size': train_sample_rows_test_size,
                 'include_only_estimators': include_only_estimators,
+                'include_batched_ensemble_estimators': include_batched_ensemble_estimators,
                 'cognito_transform_names': cognito_transform_names,
                 'positive_label': positive_label
             }
