@@ -551,9 +551,10 @@ class DataConnection(BaseDataConnection):
 
         bytes object
 
+        Auto holdout split from backend (only train data provided)
+        
         Example
         -------
-        Auto holdout split from backend (only train data provided)
         >>> train_data_connections = optimizer.get_data_connections()
         >>>
         >>> data = train_data_connections[0].read() # all train data
@@ -561,6 +562,9 @@ class DataConnection(BaseDataConnection):
         >>> X_train, X_holdout, y_train, y_holdout = train_data_connections[0].read(with_holdout_split=True) # train and holdout data
 
         User provided train and test data
+
+        Example
+        -------
         >>> optimizer.fit(training_data_reference=[DataConnection],
         >>>               training_results_reference=DataConnection,
         >>>               test_data_reference=DataConnection)
@@ -574,11 +578,11 @@ class DataConnection(BaseDataConnection):
         >>> data = train_connections[0].read() # only train data
         """
 
-        # enables flight automatically for CP4D 4.0.x, and cloud, for 3.0 and 3.5 we do not have a flight service there
+        # enables flight automatically for CP4D 4.0.x, 4.5.x and cloud, for 3.0 and 3.5 we do not have a flight service there
         use_flight = kwargs.get(
             'use_flight',
             bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ) and (
-                    self._wml_client.ICP_40 or self._wml_client.CLOUD_PLATFORM_SPACES)))
+                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.CLOUD_PLATFORM_SPACES)))
 
         # Deprecation of excel_sheet as number:
         if isinstance(excel_sheet, int):
@@ -800,7 +804,9 @@ class DataConnection(BaseDataConnection):
                 return X_train, X_holdout, y_train, y_holdout
 
             else:  # when this data connection is a test / holdout one
-                if self.auto_pipeline_params.get('prediction_columns') is not None:
+                if self.auto_pipeline_params.get('prediction_columns') or \
+                        not self.auto_pipeline_params.get('prediction_column') or \
+                        (self.auto_pipeline_params.get('prediction_column') and self.auto_pipeline_params.get('prediction_column') not in data.columns):
                     # timeseries dataset does not have prediction columns. Whole data set is returned:
                     test_X = data
                 else:
@@ -824,7 +830,7 @@ class DataConnection(BaseDataConnection):
         use_flight = kwargs.get(
             'use_flight',
             bool((self._wml_client is not None or 'USER_ACCESS_TOKEN' in os.environ) and (
-                    self._wml_client.ICP_40 or self._wml_client.CLOUD_PLATFORM_SPACES)))
+                    self._wml_client.ICP_40 or self._wml_client.ICP_45 or self._wml_client.CLOUD_PLATFORM_SPACES)))
 
         flight_parameters = kwargs.get('flight_parameters', {})
 
@@ -1223,6 +1229,10 @@ class AssetLocation(BaseLocation):
         return bucket
 
     def _get_attachment_details(self, client) -> dict:
+        if self.id is None and self.href:
+            items = self.href.split('/')
+            self.id = items[-1].split('?')[0]
+
         asset_details = client.data_assets.get_details(self.id)
 
         if 'attachment_id' in asset_details.get('metadata'):
