@@ -112,6 +112,7 @@ class FlightConnection:
                  data_size_limit: Optional[int] = 1073741824,  # 1GB in Bytes
                  logical_batch_size_limit: Optional[int] = 1073741824 * 2,  # 2GB in Bytes
                  flight_parameters: dict = None,
+                 extra_interaction_properties: dict = None,
                  fallback_to_one_connection: Optional[bool] = True,
                  number_of_batch_rows: int = None,
                  stop_after_first_batch: bool = False,
@@ -155,6 +156,10 @@ class FlightConnection:
         self.row_size = 0
         self.threads_exceptions: List['str'] = []
         self.q = queue.Queue()
+        # a threading.Condition() to notify of q or
+        # stop_reading changes
+        self.read_status_change = threading.Condition()
+
         self.subsampled_data: 'pd.DataFrame' = pd.DataFrame()
         self.data: 'pd.DataFrame' = pd.DataFrame()
         self.enable_subsampling = enable_subsampling
@@ -180,6 +185,8 @@ class FlightConnection:
         if os.environ.get('TLS_ROOT_CERTS_PATH'):
             additional_connection_args['tls_root_certs'] = os.environ.get('TLS_ROOT_CERTS_PATH')
 
+        self.extra_interaction_properties = extra_interaction_properties
+
         self.flight_location = None
         self.flight_port = None
 
@@ -192,6 +199,30 @@ class FlightConnection:
             **additional_connection_args
         )
 
+    def _q_put_nowait(self, item):
+        # we are not interested in q size increase, so no Condition waiting
+        self.q.put_nowait(item)
+
+    def _q_get(self, **kwargs):
+        # return item in q, and notify interest threads that q is changing
+        item = None
+        with self.read_status_change:
+            item = self.q.get(**kwargs)
+            self.read_status_change.notify_all()
+        return item
+
+    def _q_reset(self):
+        with self.read_status_change:
+            self.q = queue.Queue()
+            self.read_status_change.notify_all()
+
+    def _set_stop_reading(self, value):
+        # we don't need to change value while holding the lock, we just want
+        # to notify waiting threads
+        with self.read_status_change:
+            self.stop_reading = value
+            self.read_status_change.notify_all()
+
     def _set_default_flight_location(self) -> None:
         """Try to set default flight location and port from WS."""
         if not os.environ.get('FLIGHT_SERVICE_LOCATION') and self._wml_client and self._wml_client.CLOUD_PLATFORM_SPACES:
@@ -299,6 +330,13 @@ class FlightConnection:
                         )
                         yield info.endpoints
 
+                elif 'The property [infer_as_varchar] is not supported.' in str(e):
+                    # Don't sent infer_as_varchar in flight command and try again.
+                    for source_command in self._select_source_command(_use_infer_as_varchar=False):
+                        info = self.flight_client.get_flight_info(
+                            flight.FlightDescriptor.for_command(source_command)
+                        )
+                        yield info.endpoints
                 else:
                     raise WrongLocationProperty(reason=str(e))
 
@@ -350,7 +388,7 @@ class FlightConnection:
                         if self.enable_subsampling:
                             # put all data into further subsampling
                             logger.debug(f"GD {thread_number}: putting mini batch to the queue...")
-                            self.q.put_nowait((thread_number, data))
+                            self._q_put_nowait((thread_number, data))
                             logger.debug(f"GD {thread_number}: mini batch already put.")
 
                         else:
@@ -361,25 +399,25 @@ class FlightConnection:
                                 if self.total_size <= self.data_size_limit:
                                     upper_row_limit = (self.data_size_limit - self.total_size) // row_size
                                     data = data.iloc[:upper_row_limit]
-                                    self.q.put_nowait((thread_number, data))
+                                    self._q_put_nowait((thread_number, data))
                                 # --- end note
-
                                 else:
-                                    self.stop_reading = True
+                                    self._q_put_nowait((thread_number, 0))  # finish this thread
+                                    self._set_stop_reading(True)
 
                     else:
                         break
 
             logger.debug(f"GD {thread_number}: Finishing thread work...")
-            self.q.put_nowait((thread_number, 0))  # finish this thread
+            self._q_put_nowait((thread_number, 0))  # finish this thread
 
         except StopIteration:
             # Reading of batch finished, result commited."
-            self.q.put_nowait((thread_number, 0))
+            self._q_put_nowait((thread_number, 0))
 
         except Exception as e:
             logger.debug(f"GD {thread_number}: Some error occurred. Error: {e}")
-            self.q.put_nowait((thread_number, 0))
+            self._q_put_nowait((thread_number, 0))
             self.threads_exceptions.append(str(e))
 
     @staticmethod
@@ -449,11 +487,11 @@ class FlightConnection:
                     logger.debug(
                         f"QC {thread_number}: Data queue size: {data_rows} rows, max rows per batch: "
                         f"{self.number_of_batch_rows}")
-                    time.sleep(3)
+                    with self.read_status_change:
+                        self.read_status_change.wait(timeout=3)
                     continue
                 else:
                     break
-
             else:
                 data_size = sys.getsizeof(data) * self.q.qsize()
                 if data_size >= self.data_size_limit and not self.stop_reading:
@@ -461,9 +499,9 @@ class FlightConnection:
                     logger.debug(
                         f"QC {thread_number}: Data queue size: {data_size / 1024 / 1024}MB, available memory: "
                         f"{self.data_size_limit / 1024 / 1024}MB")
-                    time.sleep(3)
+                    with self.read_status_change:
+                        self.read_status_change.wait(timeout=3)
                     continue
-
                 else:
                     break
         # --- end note
@@ -496,18 +534,18 @@ class FlightConnection:
                 if row_size != 0 and not self.stop_reading:  # append batches only when we have data
                     self._chunk_queue_check(data=data, thread_number=thread_number)
                     logger.debug(f"RT {thread_number}: putting mini batch to the queue...")
-                    self.q.put_nowait((thread_number, data))
+                    self._q_put_nowait((thread_number, data))
                     logger.debug(f"RT {thread_number}: mini batch already put.")
 
                 else:
                     break
 
             logger.debug(f"RT {thread_number}: Finishing thread work...")
-            self.q.put_nowait((thread_number, 0))  # finish this thread
+            self._q_put_nowait((thread_number, 0))  # finish this thread
 
         except Exception as e:
             logger.debug(f"RT {thread_number}: Some error occurred. Error: {e}")
-            self.q.put_nowait((thread_number, 0))
+            self._q_put_nowait((thread_number, 0))
             self.threads_exceptions.append(str(e))
 
     def iterable_read(self) -> Generator:
@@ -557,13 +595,14 @@ class FlightConnection:
                 logger.debug(f"IR: Starting batch reading thread: {i}, sequence: {n}...")
                 reading_thread.start()
 
+
         for n, batch in enumerate(self.create_logical_batch(timeout=60 * 60, _type='data')):
             logger.debug(f"IR: Logical batch number {n} received.")
             logger.debug(f"IR: Passing batch to upper layer.")
             yield batch
             logger.debug(f"IR: We have control back, creating next batch...")
             if n == 0 and self.stop_after_first_batch:
-                self.stop_reading = True
+                self._set_stop_reading(True)
                 break
 
     def read(self) -> 'pd.DataFrame':
@@ -588,6 +627,7 @@ class FlightConnection:
                 else:
                     normal_read_thread = threading.Thread(target=self.normal_read)
                     normal_read_thread.start()
+                    
 
                 for n, endpoints in enumerate(self.get_endpoints()):
                     self.max_flight_batch_number = len(endpoints)  # when flight does not want to open more endpoints
@@ -598,6 +638,7 @@ class FlightConnection:
                         reading_thread = threading.Thread(target=self._get_data, args=(i, endpoint))
                         threads.append(reading_thread)
                         logger.debug(f"R: Starting batch reading thread: {i}, sequence: {n}...")
+
                         reading_thread.start()
 
             except Exception as e:
@@ -608,9 +649,10 @@ class FlightConnection:
                 for n, sequence in enumerate(sequences):
                     for i, thread in enumerate(sequence):
                         logger.debug(f"R: Joining batch reading thread {i}, sequence: {n}...")
+
                         thread.join()
 
-                self.q.put_nowait((-1, -1))  # send close queue message (stop reading logical batches)
+                self._q_put_nowait((-1, -1))  # send close queue message (stop reading logical batches)
 
                 if self.enable_subsampling:
                     subsampling_thread.join()
@@ -632,7 +674,6 @@ class FlightConnection:
             if self.enable_subsampling:
                 self.subsampled_data = self._process_data(self.subsampled_data)
                 yield self.subsampled_data
-
             else:
                 self.data = self._process_data(self.data)
                 yield self.data
@@ -650,7 +691,7 @@ class FlightConnection:
 
             self.max_flight_batch_number = 1
             sequences = []
-            self.q = queue.Queue()
+            self._q_reset()
             start_reading_threads()
 
             # Log every partition thread error (should be the flight service info included)
@@ -775,7 +816,8 @@ class FlightConnection:
                     break
 
                 logger.debug("LB: Waiting for mini batch to appear in the queue...")
-                thread_number, data = self.q.get(timeout=timeout)  # wait max 10 min
+                thread_number, data = self._q_get(timeout=timeout)  # wait max 10 min
+
                 self.q.task_done()
                 logger.debug(f"LB: Mini batch received and taken from the queue. Batch from thread: {thread_number}")
 
@@ -810,7 +852,7 @@ class FlightConnection:
                 logical_batch = [data.iloc[rows + 1:]]
                 max_rows = self._get_max_rows(_type=_type) - len(logical_batch[-1])
 
-    def _select_source_command(self, infer_schema: bool = True) -> List[str]:
+    def _select_source_command(self, infer_schema: bool = True, _use_infer_as_varchar: bool = True) -> List[str]:
         """Based on a data source type, select appropriate commands for flight service configuration."""
 
         infer_schema = infer_schema
@@ -831,6 +873,9 @@ class FlightConnection:
                 "interaction_properties": {}
             }
 
+        if self.extra_interaction_properties is not None:
+            command["interaction_properties"].update(self.extra_interaction_properties)
+
         command.update(self.flight_parameters)
 
         if self.number_of_batch_rows is not None:
@@ -887,7 +932,7 @@ class FlightConnection:
                 command['interaction_properties']['infer_schema'] = "true"
 
         # Property 'infer_as_varchar` needs to be false, when 'infer_schema' is true
-        if command['interaction_properties'].get('infer_schema', "false") == "true":
+        if command['interaction_properties'].get('infer_schema', "false") == "true" and _use_infer_as_varchar:
             command['interaction_properties'].update({'infer_as_varchar': "false"})
 
         # Git based project assets property
