@@ -31,10 +31,7 @@ def process_heartbeat(client, **kwargs):
     try:
         config_dict = kwargs.get('config_dict')
         agg_info = config_dict.get('aggregator')
-        if client:
-            wml_services_url = agg_info['ip']
-        else:
-            wml_services_url = agg_info['ip'].split('/')[0]
+        wml_services_url = agg_info['ip'].split('/')[0]
 
         hearbeat_resp = requests.get("https://" + wml_services_url + "/wml_services/training/heartbeat")
         hearbeat_resp_json = json.loads(hearbeat_resp.content.decode("utf-8"))
@@ -185,14 +182,19 @@ class Party(WMLResource):
     def start(self):
         self.Party.start()
 
-    def run(self, aggregator_id, asynchronous=True, verify=True):
+    def run(self, aggregator_id=None, experiment_id=None, asynchronous=True, verify=True, timeout: int = 60 * 10):
         """
-        Run the party with the specified aggregator_id
+        Connect to a Federated Learning aggregator and run local training.
+        Exactly one of aggregator_id and experiment_id must be supplied.  
 
         **Parameters**
 
         .. important::
            #. **aggregator_id**:  aggregator identifier\n
+              * If aggregator_id is supplied, the party will connect to the given aggregator.\n
+              **type**: str\n
+           #. **experiment_id**:  experiment identifier\n
+              * If experiment_id is supplied, the party will connect to the most recently created aggregator for the experiment.\n
               **type**: str\n
            #. **asynchronous**:\n
               * True  - party starts to run the job in the background and progress can be checked later.\n
@@ -200,13 +202,46 @@ class Party(WMLResource):
               **type**: bool\n
            #. **verify**:  verify certificate\n
               **type**: bool\n
+           #. **timeout**:  timeout in seconds.\n
+              * If the aggregator is not ready within timeout seconds, exit.\n
+              **type**: int, or None for no timeout\n
 
-        **Output**
 
-        **Example**
-         >>> party.run( aggregator_id , asynchronous = True, verify = True )
+        **Examples**
+         >>> party.run( aggregator_id = "69500105-9fd2-4326-ad27-7231aeb37ac8", asynchronous = True, verify = True )
+         >>> party.run( experiment_id = "2466fa06-1110-4169-a166-01959adec995", asynchronous = False )
 
         """
+        from ibmfl.exceptions import FLException
+        from datetime import datetime
+        import time
+
+        timeout_time = None if timeout is None else timeout + time.time()
+        if ( experiment_id is None and aggregator_id is None ) or ( experiment_id is not None and aggregator_id is not None ) :
+            raise FLException("Exactly one of aggregator_id and experiment_id must be supplied")
+
+        if ( experiment_id is not None ):
+            while True: 
+                try:
+                    details = self._client.training.get_details(get_all=True,training_definition_id=experiment_id)['resources']
+                    details = [ d for d in details if d['entity']['status']['state'] in ['accepting_parties','pending','running'] ]
+                    if not details :
+                        if timeout_time and timeout_time < time.time() :
+                            raise FLException("Cannot find an aggregator for experiment %s" % experiment_id)
+                        else :
+                            logger.info("Cannot find an aggregator for experiment %s . Retrying." % experiment_id)
+                            time.sleep(30)
+                            continue
+                    else :
+                        aggregator_id = max( [(t['metadata']['id'],datetime.strptime(t['metadata']['created_at'],'%Y-%m-%dT%H:%M:%S.%fZ'))
+                                          for t in details],key=lambda d:d[1])[0]
+                        logger.info("Using aggregator id %s" % aggregator_id) 
+                        break
+                except Exception as ex:
+                    logger.exception(ex)
+                    raise FLException(str(ex))
+
+
         #import the changed files in the desired lib version
 
         config_dict = self.args.get('config_dict')
@@ -220,30 +255,28 @@ class Party(WMLResource):
         }
         if 'metrics_recorder' not in config_dict:
             config_dict["metrics_recorder"] = metrics_config
-        agg_info = config_dict.get('aggregator').get('ip') + "/ml/v4/trainings/" + aggregator_id
+        agg_info = config_dict.get('aggregator').get('ip').split('/')[0] + "/ml/v4/trainings/" + aggregator_id
         config_dict['aggregator']['ip'] = agg_info
         self.args['config_dict'] = config_dict
 
         #check for aggregator state and start job
-        import time
-        from ibmfl.exceptions import FLException
         try:
             training_status = self._client.training.get_status(aggregator_id)
             state = training_status['state']
             ready = False
             if state == "pending":
-                while state == "pending":
+                while state == "pending" and ( not timeout_time or timeout_time > time.time() ) :
                     logger.info("Waiting for aggregator accepting parties state..")
+                    time.sleep(10)
                     training_status = self._client.training.get_status(aggregator_id)
                     state = training_status['state']
-                    time.sleep(10)
                 if state != "accepting_parties":
-                    raise FLException("The current state of training is %s, so the party is not able to start a job." % state)
+                    raise FLException("The current state of training %s is %s, so the party is not able to start a job." % (aggregator_id,state))
                 ready = True
             elif state == "running" or state == "accepting_parties":
                 ready = True
             else:
-                raise FLException("The current state of training is %s, so the party is not able to start a job." % state)
+                raise FLException("The current state of training %s is %s, so the party is not able to start a job." % (aggregator_id,state))
 
             if ready:
                 if "cpd406" in self.module_location or "cloud" in self.module_location:
@@ -262,7 +295,7 @@ class Party(WMLResource):
                 self.connection = self.Party.connection
                 self.start()
             else:
-                raise FLException("The current state of training is %s, so the party is not able to start a job." % state)
+                raise FLException("The current state of training %s is %s, so the party is not able to start a job." % (aggregator_id,state))
             #wait for the job to finish if synchrounous
             if not asynchronous:
                 while "completed" != state and "failed" != state and "canceled" != state and self.is_running():
