@@ -58,12 +58,9 @@ class PkgExtn(WMLResource):
         """
         PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
 
-        if not self._ICP:
-            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                      headers=self._client._get_headers())
+        response = requests.get(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
+
         if response.status_code == 200:
             return self._get_required_element_from_response(self._handle_response(200, u'get hw spec details', response))
         else:
@@ -115,16 +112,11 @@ class PkgExtn(WMLResource):
         pkg_extn_meta_json = json.dumps(pkg_extn_meta)
 
         PkgExtn._validate_type(file_path, u'file_path', str, True)
-        ##Step1: Create a pkg extn
-        f = {'file': open(file_path, 'rb')}
         #Step1  : Create an asset
         print("Creating package extensions")
         href = self._client.service_instance._href_definitions.get_pkg_extns_href()
 
-        if not self._ICP:
-            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=pkg_extn_meta_json)
-        else:
-            creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=pkg_extn_meta_json)
+        creation_response = requests.post(href, params=self._client._params(), headers=self._client._get_headers(), data=pkg_extn_meta_json)
 
         pkg_extn_details = self._handle_response(201, u'creating new package_extensions', creation_response)
 
@@ -133,16 +125,46 @@ class PkgExtn(WMLResource):
             pkg_extn_asset_id = pkg_extn_details["metadata"]["asset_id"]
             pkg_extn_presigned_url = pkg_extn_details["entity"]["package_extension"]["href"]
 
+            FILE_SIZE_LIMIT = int(0.3 * 1073741824)
+
+            def read_in_chunks(chunk_size=FILE_SIZE_LIMIT):
+                with open(file_path, 'rb') as file_object:
+                    while True:
+                        data = file_object.read(chunk_size)
+                        if not data:
+                            break
+                        yield data
+
+            def send_multipart_request(file, url):
+                content_path = os.path.abspath(file)
+                content_size = os.stat(content_path).st_size
+
+                index = 0
+                headers = {}
+
+                for chunk in read_in_chunks(FILE_SIZE_LIMIT):
+                    offset = index + len(chunk)
+                    headers['Content-Range'] = 'bytes %s-%s/%s' % (index, offset - 1, content_size)
+                    index = offset
+
+                    response = requests.put(
+                        url,
+                        files={"file": chunk}
+                    )
+
+                return response
+
+            if os.stat(file_path).st_size == 0:
+                raise WMLClientError('Package extension file cannot be empty')
+
             if not self._ICP:
                 put_response = requests.put(
                     pkg_extn_presigned_url,
-                    data=open(file_path, 'rb').read(),
+                    data=read_in_chunks()
                 )
             else:
-                put_response = requests.put(
-                    self._wml_credentials['url'] + pkg_extn_presigned_url,
-                    files=f
-                )
+                put_response = send_multipart_request(file_path, self._wml_credentials['url'] + pkg_extn_presigned_url)
+
             if put_response.status_code == 201 or put_response.status_code == 200:
                 # Step3: Mark the upload complete
                 complete_response = requests.post(
@@ -181,10 +203,8 @@ class PkgExtn(WMLResource):
 
         href = self._client.service_instance._href_definitions.get_pkg_extns_href()
 
-        if not self._ICP:
-            response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
-        else:
-            response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
+        response = requests.get(href, params=self._client._params(), headers=self._client._get_headers())
+
         self._handle_response(200, u'list pkg_extn', response)
         asset_details = self._handle_response(200, u'list assets', response)["resources"]
         pkg_extn_values = [
@@ -287,15 +307,11 @@ class PkgExtn(WMLResource):
 
         parameters = self._client._params()
         parameters.update(name=pkg_extn_name)
-        if not self._ICP:
-            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extns_href(),
-                                    params=parameters,
-                                    headers=self._client._get_headers())
-        else:
 
-            response = requests.get(self._client.service_instance._href_definitions.get_pkg_extns_href(),
-                                    params=parameters,
-                                    headers=self._client._get_headers())
+        response = requests.get(self._client.service_instance._href_definitions.get_pkg_extns_href(),
+                                params=parameters,
+                                headers=self._client._get_headers())
+
         if response.status_code == 200:
             total_values = self._handle_response(200, u'get pkg extn', response)["total_results"]
             if total_values != 0:
@@ -388,12 +404,9 @@ class PkgExtn(WMLResource):
         """
         PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
 
-        if not self._ICP:
-            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                    headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                      headers=self._client._get_headers())
+        response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+                                headers=self._client._get_headers())
+
         if response.status_code == 200:
             return self._get_required_element_from_response(response.json())
         else:
@@ -403,12 +416,8 @@ class PkgExtn(WMLResource):
     def _delete(self, pkg_extn_uid):
         PkgExtn._validate_type(pkg_extn_uid, u'pkg_extn_uid', STR_TYPE, True)
 
-        if not self._ICP:
-            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                       headers=self._client._get_headers())
-        else:
-            response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
-                                       headers=self._client._get_headers())
+        response = requests.delete(self._client.service_instance._href_definitions.get_pkg_extn_href(pkg_extn_uid), params=self._client._params(),
+                                   headers=self._client._get_headers())
 
     def _get_required_element_from_response(self, response_data):
 
