@@ -50,6 +50,7 @@ class ClassificationAlgorithms(Enum):
     SnapRF = "SnapRandomForestClassifier"
     SnapSVM = "SnapSVMClassifier"
     SnapLR = "SnapLogisticRegression"
+    SnapBM = "SnapBoostingMachineClassifier"
 
 
 class ClassificationAlgorithmsCP4D(Enum):
@@ -69,6 +70,18 @@ class ClassificationAlgorithmsCP4D(Enum):
     SnapRF = "SnapRandomForestClassifier"
     SnapSVM = "SnapSVMClassifier"
     SnapLR = "SnapLogisticRegression"
+    SnapBM = "SnapBoostingMachineClassifier"
+
+
+class BatchedClassificationAlgorithms(Enum):
+    """Batched tree ensemble classification algorithms that AutoAI could use for IBM Cloud."""
+    RF = "BatchedTreeEnsembleClassifier(RandomForestClassifier)"
+    EX_TREES = "BatchedTreeEnsembleClassifier(ExtraTreesClassifier)"
+    LGBM = "BatchedTreeEnsembleClassifier(LGBMClassifier)"
+    XGB = "BatchedTreeEnsembleClassifier(XGBClassifier)"
+    GB = "BatchedTreeEnsembleClassifier(GradientBoostingClassifier)"
+    SnapRF = "BatchedTreeEnsembleClassifier(SnapRandomForestClassifier)"
+    SnapBM = "BatchedTreeEnsembleClassifier(SnapBoostingMachineClassifier)"
 
 
 class RegressionAlgorithms(Enum):
@@ -105,6 +118,17 @@ class RegressionAlgorithmsCP4D(Enum):
     SnapBM = "SnapBoostingMachineRegressor"
 
 
+class BatchedRegressionAlgorithms(Enum):
+    """Batched tree ensemble regression algorithms that AutoAI could use for IBM Cloud."""
+    RF = "BatchedTreeEnsembleRegressor(RandomForestRegressor)"
+    EX_TREES = "BatchedTreeEnsembleRegressor(ExtraTreesRegressor)"
+    LGBM = "BatchedTreeEnsembleRegressor(LGBMRegressorEstimator)"
+    GB = "BatchedTreeEnsembleRegressor(GradientBoostingRegressor)"
+    SnapRF = "BatchedTreeEnsembleRegressor(SnapRandomForestRegressor)"
+    SnapBM = "BatchedTreeEnsembleRegressor(SnapBoostingMachineRegressor)"
+    XGB = "BatchedTreeEnsembleRegressor(XGBRegressor)"
+
+
 class ForecastingAlgorithmsCP4D(Enum):
     """Forecasting algorithms that AutoAI could use for IBM Cloud."""
     LR = "LinearRegression"
