@@ -401,4 +401,9 @@ class InconsistentImputationListElements(WMLClientError, ValueError):
 
 class ImputationListNotSupported(WMLClientError, ValueError):
     def __init__(self):
-        WMLClientError.__init__(self, f'List passed as imputation strategy is not supported for non-forecasting scenarios.')
\ No newline at end of file
+        WMLClientError.__init__(self, f'List passed as imputation strategy is not supported for non-forecasting scenarios.')
+
+
+class InvalidSamplingType(WMLClientError, ValueError):
+    def __init__(self, sampling_type: str, predcition_type: str):
+        WMLClientError.__init__(self, f"Sampling type for {sampling_type} is invalid for prediction type {predcition_type}.")
